=============================
MerkavaDB
=============================

.. image:: https://badge.fury.io/py/merkava.png
    :target: http://badge.fury.io/py/merkava

.. image:: https://travis-ci.org/ahopkins/merkava.png?branch=master
    :target: https://travis-ci.org/ahopkins/merkava

A fast ordered NoSQL database.


Features
--------

* TODO

